==> php-residence_0.3.tar.gz: php-residence/includes/lang/en/modifica_cliente.php <==
<?php

switch ($messaggio) {

case "Il cognome verr cambiato da":  		$messaggio = "The surname will be changed from"; break;
case "a":  					$messaggio = "to"; break;
case "Il nome verr cambiato da":  		$messaggio = "The name will be changed from"; break;
case "Il sesso verr cambiato a":  		$messaggio = "The gender will be changed to "; break;
case "La data di nascita  verr cambiata da":  	$messaggio = "The birthday will be changed from"; break;
case "Il telefono verr cambiato da":  		$messaggio = "The telephone will be changed from"; break;
case "La via  verr cambiata da":  		$messaggio = "The street will be changed from"; break;
case "Il numero civico verr cambiato da":  	$messaggio = "The street number will be changed from"; break;
case "La citt di residenza verr cambiata da":	$messaggio = "The city will be changed from"; break;
case "La nazione verr cambiata da":  		$messaggio = "The nation will be changed from"; break;
case "Il CAP verr cambiato da":  		$messaggio = "The postal code will be changed from"; break;
case "Il fax verr cambiato da":  		$messaggio = "The fax will be changed from"; break;
case "L' email verr cambiata da":  		$messaggio = "The email will be changed from"; break;
case "Il 2 telefono verr cambiato da":  	$messaggio = "The 2nd telephone will be changed from"; break;
case "Il 3 telefono verr cambiato da":  	$messaggio = "The 3rd telephone will be changed from"; break;
case "Il cognome n2 verr cambiato da":  	$messaggio = "The surname No2 will be changed from"; break;
case "Il nome n2 verr cambiato da":  		$messaggio = "The name No2 will be changed from"; break;
case "Il sesso n2 verr cambiato a":  		$messaggio = "The gender No2 will be changed to "; break;
case "La data di nascita n2 verr cambiata da":	$messaggio = "The birthday No2 will be changed from"; break;
case "Il <b>commento</b> verr cambiato":  	$messaggio = "The <b>comment</b> will be changed"; break;
case "Il <b>nome</b> verr cancellato":  	$messaggio = "The <b>name</b> will be deleted"; break;
case "La <b>data di nascita</b>  verr cancellata":	$messaggio = "The <b>birthday</b> will be deleted"; break;
case "Il <b>telefono</b> verr cancellato":  	$messaggio = "The <b>telephone</b> will be deleted"; break;
case "La <b>via</b> verr cancellata":  	$messaggio = "The <b>street</b> will be deleted"; break;
case "Il <b>n civico</b> verr cancellato":  	$messaggio = "The <b>street number</b> will be deleted"; break;
case "La <b>citt</b>  verr cancellata":  	$messaggio = "The <b>city</b> will be deleted"; break;
case "La <b>nazione</b> verr cancellata":  	$messaggio = "The <b>nation</b> will be deleted"; break;
case "Il <b>CAP</b> verr cancellato":  	$messaggio = "The <b>postal code</b> will be deleted"; break;
case "Il <b>fax</b> verr cancellato":  	$messaggio = "The <b>fax</b> will be deleted"; break;
case "L' <b>email</b>  verr cancellata":  	$messaggio = "The <b>email</b> will be deleted"; break;
case "Il <b>2 telefono</b> verr cancellato":	$messaggio = "The <b>2nd telephone</b> will be deleted"; break;
case "Il <b>3 telefono</b> verr cancellato":	$messaggio = "The <b>3rd telephone</b> will be deleted"; break;
case "Il <b>cognome n 2</b> verr cancellato":	$messaggio = "The <b>surname No2</b> will be deleted"; break;
case "Il <b>nome n 2</b> verr cancellato":	$messaggio = "The <b>name No2</b> will be deleted"; break;
case "La <b>data di nascita n 2</b>  verr cancellata":	$messaggio = "The <b>birthday No2</b> will be deleted"; break;
case "Continua":  				$messaggio = "Continue"; break;
case "Il cliente":  				$messaggio = "Client"; break;
case " stato modificato":  			$messaggio = "has been modified"; break;
case "Torna indietro":  			$messaggio = "Go back"; break;
case "Modifica i dati del cliente":  		$messaggio = "Modify data of client"; break;
case "Cognome":  				$messaggio = "Surame"; break;
case "cambia in":  				$messaggio = "change to"; break;
case "Nome":  					$messaggio = "Name"; break;
case "cancella":  				$messaggio = "delete"; break;
case "Sesso":  					$messaggio = "Gender"; break;
case "Data di nascita":  			$messaggio = "Birthday"; break;
case "Telefono":  				$messaggio = "Telephone"; break;
case "Via":  					$messaggio = "Street"; break;
case "Piazza":  				$messaggio = "Square"; break;
case "Viale":  					$messaggio = "Avenue"; break;
case "Piazzale":  				$messaggio = "Boulevard"; break;
case "Vicolo":  				$messaggio = "Road"; break;
case "Numero civico":  				$messaggio = "Street number"; break;
case "Citt":  					$messaggio = "City"; break;
case "Nazione":  				$messaggio = "Nation"; break;
case "CAP":  					$messaggio = "Postal code"; break;
case "Fax":  					$messaggio = "Fax"; break;
case "Email":  					$messaggio = "Email"; break;
case "2 telefono":  				$messaggio = "2nd telephone"; break;
case "3 telefono":  				$messaggio = "3rd telephone"; break;
case "Cognome n2":  				$messaggio = "Surname No2"; break;
case "Nome n2":  				$messaggio = "Name No2"; break;
case "Sesso n2":  				$messaggio = "Gender No2"; break;
case "Data di nascita n2":  			$messaggio = "Birthday No2"; break;
case "Commento":  				$messaggio = "Comment"; break;
case "Visualizza il contratto":  		$messaggio = "View the contract"; break;
case "di tipo":  				$messaggio = "type"; break;
case "Prenotazioni del cliente":  		$messaggio = "Reservations of client"; break;
case "nel":  					$messaggio = "in"; break;
case "Cognome_del_cliente":  			$messaggio = "Client_surname"; break;
case "Data_iniziale":  				$messaggio = "Starting_date"; break;
case "Data_finale":  				$messaggio = "Ending_date"; break;
case "Tariffa_completa":  			$messaggio = "Complete_fare"; break;
case "Caparra":  				$messaggio = "Deposit"; break;
case "Pagato":  				$messaggio = "Paid"; break;
case "App.":  					$messaggio = "Apa."; break;
case "Commento":  				$messaggio = "Comment"; break;
case "TOTALE":  				$messaggio = "TOTAL"; break;
case "Pers":  					$messaggio = "Peop"; break;
case "":  		$messaggio = ""; break;
case "":  		$messaggio = ""; break;
case "":  		$messaggio = ""; break;

} # fine switch ($messaggio)

?>

==> php-residence_0.4.3.tar.gz: php-residence/includes/lang/en/modifica_cliente.php <==
<?php

switch ($messaggio) {

case "Il cognome verr cambiato da":  		$messaggio = "The surname will be changed from"; break;
case "a":  					$messaggio = "to"; break;
case "Il nome verr cambiato da":  		$messaggio = "The name will be changed from"; break;
case "Il sesso verr cambiato a":  		$messaggio = "The gender will be changed to "; break;
case "La data di nascita  verr cambiata da":  	$messaggio = "The birthday will be changed from"; break;
case "Il telefono verr cambiato da":  		$messaggio = "The telephone will be changed from"; break;
case "La via  verr cambiata da":  		$messaggio = "The street will be changed from"; break;
case "Il numero civico verr cambiato da":  	$messaggio = "The street number will be changed from"; break;
case "La citt di residenza verr cambiata da":	$messaggio = "The city will be changed from"; break;
case "La nazione verr cambiata da":  		$messaggio = "The nation will be changed from"; break;
case "Il CAP verr cambiato da":  		$messaggio = "The postal code will be changed from"; break;
case "Il fax verr cambiato da":  		$messaggio = "The fax will be changed from"; break;
case "L' email verr cambiata da":  		$messaggio = "The email will be changed from"; break;
case "Il 2 telefono verr cambiato da":  	$messaggio = "The 2nd telephone will be changed from"; break;
case "Il 3 telefono verr cambiato da":  	$messaggio = "The 3rd telephone will be changed from"; break;
case "Il cognome n2 verr cambiato da":  	$messaggio = "The surname No2 will be changed from"; break;
case "Il nome n2 verr cambiato da":  		$messaggio = "The name No2 will be changed from"; break;
case "Il sesso n2 verr cambiato a":  		$messaggio = "The gender No2 will be changed to "; break;
case "La data di nascita n2 verr cambiata da":	$messaggio = "The birthday No2 will be changed from"; break;
case "Il <b>commento</b> verr cambiato":  	$messaggio = "The <b>comment</b> will be changed"; break;
case "Il <b>nome</b> verr cancellato":  	$messaggio = "The <b>name</b> will be deleted"; break;
case "La <b>data di nascita</b>  verr cancellata":	$messaggio = "The <b>birthday</b> will be deleted"; break;
case "Il <b>telefono</b> verr cancellato":  	$messaggio = "The <b>telephone</b> will be deleted"; break;
case "La <b>via</b> verr cancellata":  	$messaggio = "The <b>street</b> will be deleted"; break;
case "Il <b>n civico</b> verr cancellato":  	$messaggio = "The <b>street number</b> will be deleted"; break;
case "La <b>citt</b>  verr cancellata":  	$messaggio = "The <b>city</b> will be deleted"; break;
case "La <b>nazione</b> verr cancellata":  	$messaggio = "The <b>nation</b> will be deleted"; break;
case "Il <b>CAP</b> verr cancellato":  	$messaggio = "The <b>postal code</b> will be deleted"; break;
case "Il <b>fax</b> verr cancellato":  	$messaggio = "The <b>fax</b> will be deleted"; break;
case "L' <b>email</b>  verr cancellata":  	$messaggio = "The <b>email</b> will be deleted"; break;
case "Il <b>2 telefono</b> verr cancellato":	$messaggio = "The <b>2nd telephone</b> will be deleted"; break;
case "Il <b>3 telefono</b> verr cancellato":	$messaggio = "The <b>3rd telephone</b> will be deleted"; break;
case "Il <b>cognome n 2</b> verr cancellato":	$messaggio = "The <b>surname No2</b> will be deleted"; break;
case "Il <b>nome n 2</b> verr cancellato":	$messaggio = "The <b>name No2</b> will be deleted"; break;
case "La <b>data di nascita n 2</b>  verr cancellata":	$messaggio = "The <b>birthday No2</b> will be deleted"; break;
case "Continua":  				$messaggio = "Continue"; break;
case "Il cliente":  				$messaggio = "Client"; break;
case " stato modificato":  			$messaggio = "has been modified"; break;
case "Torna indietro":  			$messaggio = "Go back"; break;
case "Modifica i dati del cliente":  		$messaggio = "Modify data of client"; break;
case "Cognome":  				$messaggio = "Surame"; break;
case "cambia in":  				$messaggio = "change to"; break;
case "Nome":  					$messaggio = "Name"; break;
case "cancella":  				$messaggio = "delete"; break;
case "Sesso":  					$messaggio = "Gender"; break;
case "Data di nascita":  			$messaggio = "Birthday"; break;
case "Telefono":  				$messaggio = "Telephone"; break;
case "Via":  					$messaggio = "Street"; break;
case "Piazza":  				$messaggio = "Square"; break;
case "Viale":  					$messaggio = "Avenue"; break;
case "Piazzale":  				$messaggio = "Boulevard"; break;
case "Vicolo":  				$messaggio = "Road"; break;
case "Numero civico":  				$messaggio = "Street number"; break;
case "Citt":  					$messaggio = "City"; break;
case "Nazione":  				$messaggio = "Nation"; break;
case "CAP":  					$messaggio = "Postal code"; break;
case "Fax":  					$messaggio = "Fax"; break;
case "Email":  					$messaggio = "Email"; break;
case "2 telefono":  				$messaggio = "2nd telephone"; break;
case "3 telefono":  				$messaggio = "3rd telephone"; break;
case "Cognome n2":  				$messaggio = "Surname No2"; break;
case "Nome n2":  				$messaggio = "Name No2"; break;
case "Sesso n2":  				$messaggio = "Gender No2"; break;
case "Data di nascita n2":  			$messaggio = "Birthday No2"; break;
case "Commento":  				$messaggio = "Comment"; break;
case "Visualizza il contratto":  		$messaggio = "View the contract"; break;
case "di tipo":  				$messaggio = "type"; break;
case "Prenotazioni del cliente":  		$messaggio = "Reservations of client"; break;
case "nel":  					$messaggio = "in"; break;
case "Cognome_del_cliente":  			$messaggio = "Client_surname"; break;
case "Data_iniziale":  				$messaggio = "Starting_date"; break;
case "Data_finale":  				$messaggio = "Ending_date"; break;
case "Tariffa_completa":  			$messaggio = "Complete_fare"; break;
case "Caparra":  				$messaggio = "Deposit"; break;
case "Pagato":  				$messaggio = "Paid"; break;
case "App.":  					$messaggio = "Apa."; break;
case "Commento":  				$messaggio = "Comment"; break;
case "TOTALE":  				$messaggio = "TOTAL"; break;
case "Pers":  					$messaggio = "Peop"; break;
case "Inserito da":  				$messaggio = "Inserted by"; break;
case "Si considerer l'utente":  		$messaggio = "User"; break;
case "come colui che ha inserito il cliente":	$messaggio = "will be considered as the one who inserted the client"; break;
case "":  		$messaggio = ""; break;
case "":  		$messaggio = ""; break;

} # fine switch ($messaggio)

?>
